@@ -11,7 +11,7 @@
 
 #include "pk11hpke.h"
 
-/* draft-08, shared-mode only.
+/* draft-09, supporting shared-mode and split-mode as a backend server only.
  * Notes on the implementation status:
  * - Padding (https://tools.ietf.org/html/draft-ietf-tls-esni-08#section-6.2),
  *   is not implemented (see bug 1677181).
@@ -21,12 +21,10 @@
  * - Some of the buffering (construction/compression/decompression) could likely
  *   be optimized, but the spec is still evolving so that work is deferred.
  */
-#define TLS13_ECH_VERSION 0xfe08
+#define TLS13_ECH_VERSION 0xfe09
 #define TLS13_ECH_SIGNAL_LEN 8
 
 static const char kHpkeInfoEch[] = "tls ech";
-static const char kHpkeInfoEchHrr[] = "tls ech hrr key";
-static const char kHpkeLabelHrrPsk[] = "hrr key";
 static const char hHkdfInfoEchConfigID[] = "tls ech config id";
 static const char kHkdfInfoEchConfirm[] = "ech accept confirmation";
 
@@ -45,11 +43,23 @@ struct sslEchConfigContentsStr {
 struct sslEchConfigStr {
     PRCList link;
     SECItem raw;
-    PRUint8 configId[32];
+    PRUint8 configId[8];
     PRUint16 version;
     sslEchConfigContents contents;
 };
 
+struct sslEchXtnStateStr {
+    SECItem innerCh;          /* Server: ClientECH.payload */
+    SECItem senderPubKey;     /* Server: ClientECH.enc */
+    SECItem configId;         /* Server: ClientECH.config_id  */
+    HpkeKdfId kdfId;          /* Server: ClientECH.cipher_suite.kdf */
+    HpkeAeadId aeadId;        /* Server: ClientECH.cipher_suite.aead */
+    SECItem retryConfigs;     /* Client: ServerECH.retry_configs*/
+    PRBool retryConfigsValid; /* Client: Extraction of retry_configss is allowed.
+                               *  This is set once the handshake completes (having
+                               *  verified to the ECHConfig public name). */
+};
+
 SECStatus SSLExp_EncodeEchConfig(const char *publicName, const PRUint32 *hpkeSuites,
                                  unsigned int hpkeSuiteCount, HpkeKemId kemId,
                                  const SECKEYPublicKey *pubKey, PRUint16 maxNameLen,
@@ -69,14 +79,15 @@ SECStatus tls13_ConstructClientHelloWithEch(sslSocket *ss, const sslSessionID *s
 SECStatus tls13_CopyEchConfigs(PRCList *oconfigs, PRCList *configs);
 SECStatus tls13_DecodeEchConfigs(const SECItem *data, PRCList *configs);
 void tls13_DestroyEchConfigs(PRCList *list);
+void tls13_DestroyEchXtnState(sslEchXtnState *state);
 SECStatus tls13_GetMatchingEchConfig(const sslSocket *ss, HpkeKdfId kdf, HpkeAeadId aead,
                                      const SECItem *configId, sslEchConfig **cfg);
 SECStatus tls13_MaybeHandleEch(sslSocket *ss, const PRUint8 *msg, PRUint32 msgLen, SECItem *sidBytes,
                                SECItem *comps, SECItem *cookieBytes, SECItem *suites, SECItem **echInner);
-SECStatus tls13_MaybeHandleEchSignal(sslSocket *ss);
+SECStatus tls13_MaybeHandleEchSignal(sslSocket *ss, const PRUint8 *savedMsg, PRUint32 savedLength);
 SECStatus tls13_MaybeAcceptEch(sslSocket *ss, const SECItem *sidBytes, const PRUint8 *chOuter,
                                unsigned int chOuterLen, SECItem **chInner);
 SECStatus tls13_MaybeGreaseEch(sslSocket *ss, unsigned int prefixLen, sslBuffer *buf);
-SECStatus tls13_WriteServerEchSignal(sslSocket *ss);
+SECStatus tls13_WriteServerEchSignal(sslSocket *ss, PRUint8 *sh, unsigned int shLen);
 
 #endif
